@@ -14,18 +14,26 @@ pub(crate) struct ContextPrintingSink<P: Printer> {
     printer: P,
 }
 
-/// Error represents an error that happens during the search process
+/// `Error` represents an error that happens during the search process
 ///
-/// The `SearchError` variant is specifically used to represent errors reported by the internal grep library, and
-/// their reasons may not be specifically matchable as a result.
 #[derive(Error, Debug)]
 pub enum Error {
+    /// Printing to the given printer failed due to an i/o error.
     #[error("Print failure: {0}")]
-    PrintFailed(io::Error),
+    PrintFailed(
+        /// The original i/o error that caused the print failure.
+        io::Error,
+    ),
+
+    /// The `SearchError` variant is specifically used to represent errors reported by the internal grep library, and
+    /// their reasons may not be specifically matchable as a result.
     // This error is a bit custom, and is intended to be produced by callers on the SinkError trait. As such,
     // the message is just a passthrough
     #[error("{0}")]
-    SearchError(String),
+    SearchError(
+        /// An error message provided by the underlying grep library.
+        String,
+    ),
 }
 
 impl From<print::Error> for Error {
@@ -88,10 +96,9 @@ impl<P: Printer> Sink for ContextPrintingSink<P> {
     ) -> Result<bool, Self::Error> {
         Self::validate_searcher(searcher);
 
-        let print_res = self.printer.colored_print(
-            Fg(LightRed),
-            std::str::from_utf8(sink_match.bytes()).unwrap(),
-        );
+        let print_res = self
+            .printer
+            .colored_print(Fg(LightRed), String::from_utf8_lossy(sink_match.bytes()));
 
         Self::get_sink_result_for_print_result(print_res)
     }
@@ -103,7 +110,7 @@ impl<P: Printer> Sink for ContextPrintingSink<P> {
     ) -> Result<bool, Self::Error> {
         Self::validate_searcher(searcher);
 
-        let data = std::str::from_utf8(context.bytes()).unwrap();
+        let data = String::from_utf8_lossy(context.bytes());
         let print_res = self.printer.print(data);
 
         Self::get_sink_result_for_print_result(print_res)
